@@ -1,7 +1,6 @@
 from os.path import abspath, dirname, join
 
 from IPython.terminal.interactiveshell import KeyBindingManager
-from IPython.utils.py3compat import string_types
 
 
 def name(c):
@@ -40,7 +39,7 @@ def multi_filter_str(flt):
     yield name(flt)
 
 
-log_filters = dict(_AndList='And', _OrList='Or')
+log_filters = {'_AndList': 'And', '_OrList': 'Or'}
 log_invert =  {'_Invert'}
 
 kbm = KeyBindingManager.for_prompt()
@@ -54,14 +53,14 @@ if common_docs:
 
 dummy_docs = list(set(dummy_docs))
 
-single_filter = dict()
-multi_filter = dict()
+single_filter = {}
+multi_filter =  {}
 for kb in ipy_bindings:
     doc = kb.handler.__doc__
     if not doc or doc in dummy_docs:
         continue
 
-    shortcut = ' '.join([k if isinstance(k, string_types) else k.name for k in kb.keys])
+    shortcut = ' '.join([k if isinstance(k, str) else k.name for k in kb.keys])
     shortcut += shortcut.endswith('\\') and '\\' or ''
     if hasattr(kb.filter, 'filters'):
         flt = ' '.join(multi_filter_str(kb.filter))
